BitmapFontCharacter class

A single character in a BitmapFont.

Constructors

BitmapFontCharacter(int id, int width, int height, int xOffset, int yOffset, int xAdvance, int page, int channel)

Properties

channel → int
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
final
id → int
final
image → Image
final
page → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int
final
xAdvance → int
final
xOffset → int
final
yOffset → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited