ExrImage class

Implemented types

Constructors

ExrImage(Uint8List bytes)

Properties

backgroundColor → Color?
The suggested background color of the canvas.
no setteroverride
flags ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
The height of the image canvas.
getter/setter pairoverride-getter
numFrames → int
The number of frames that can be decoded.
no setteroverride
numParts → int
no setter
parts → List<ExrPart>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version ↔ int?
getter/setter pair
width ↔ int
The width of the image canvas.
getter/setter pairoverride-getter

Methods

getPart(int i) → ExrPart
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

isValidFile(List<int> bytes) → bool
Parse just enough of the file to identify that it's an EXR image.

Constants

allFlags → const int
Bitwise OR of all supported flags.
exrVersion → const int
Value that goes into VERSION_NUMBER_FIELD.
longNamesFlag → const int
File contains long attribute or channel names
multiPartFileFlag → const int
File has multiple parts.
nonImageFlag → const int
File has at least one part which is not a regular scanline image or regular tiled image (that is, it is a deep format).
signature → const int
The signature number is stored in the first four bytes of every OpenEXR image file. This can be used to quickly test whether a given file is an OpenEXR image file (see isImfMagic(), below).
tiledFlag → const int
File is tiled