GifColorMap class

Constructors

GifColorMap(int numColors)
GifColorMap.from(GifColorMap other)

Properties

bitsPerPixel ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
numColors ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transparent ↔ int?
getter/setter pair

Methods

alpha(int color) → int
blue(int color) → int
color(int index) → ColorUint8
getPalette() → PaletteUint8
green(int color) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
red(int color) → int
setColor(int index, int r, int g, int b) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited