GifEncoder class

Inheritance

Constructors

GifEncoder({int delay = 80, int repeat = 0, int numColors = 256, QuantizerType quantizerType = QuantizerType.neural, int samplingFactor = 10, DitherKernel dither = DitherKernel.floydSteinberg, bool ditherSerpentine = false})

Properties

delay ↔ int
getter/setter pair
dither ↔ DitherKernel
getter/setter pair
ditherSerpentine ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
numColors ↔ int
getter/setter pair
output ↔ OutputBuffer?
getter/setter pair
quantizerType ↔ QuantizerType
getter/setter pair
repeat ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samplingFactor ↔ int
getter/setter pair
supportsAnimation → bool
Does this encoder support animation?
no setteroverride

Methods

addFrame(Image image, {int? duration}) → void
This adds the frame passed to image. After the last frame has been added, finish is required to be called. Optional frame duration is in 1/100 sec.
encode(Image image, {bool singleFrame = false}) → Uint8List
Encode a single frame image.
override
finish() → Uint8List?
Encode the images that were added with addFrame. After this has been called (returning the finishes GIF), calling addFrame for a new animation or image is safe again.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited