IcoBmpInfo class

Implemented types

Constructors

IcoBmpInfo(InputBuffer p, {BmpFileHeader? fileHeader})

Properties

alphaMask ↔ int
getter/setter pairinherited
backgroundColor → Color?
The suggested background color of the canvas.
no setterinherited
bitsPerPixel → int
finalinherited
blueMask ↔ int
getter/setter pairinherited
compression → BmpCompression
finalinherited
greenMask ↔ int
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
finalinherited
headerSize → int
finalinherited
height → int
The height of the image canvas.
no setter
ignoreAlphaChannel → bool
no setter
imageSize → int
finalinherited
importantColors → int
finalinherited
numFrames → int
The number of frames that can be decoded.
no setterinherited
palette ↔ PaletteUint8?
getter/setter pairinherited
planes → int
finalinherited
readBottomUp → bool
no setterinherited
redMask ↔ int
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalColors → int
finalinherited
width → int
finalinherited
xppm → int
finalinherited
yppm → int
finalinherited

Methods

decodePixel(InputBuffer input, void pixel(num r, num g, num b, num a)) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readPalette(InputBuffer input) → void
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited