IcoInfoImage class

Constructors

IcoInfoImage({required int width, required int height, required int colorPalette, required int bytesSize, required int bytesOffset, required int colorPlanes, required int bitsPerPixel})

Properties

bitsPerPixel → int
final
bytesOffset → int
final
bytesSize → int
final
colorPalette → int
final
colorPlanes → int
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited