IfdDirectory class

An EXIF IfdDirectory stores a collection of IFD tags and values.

Properties

getter/setter pair
data → Map<int, IfdValue>
final
hasCopyright → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasImageDescription → bool
no setter
hasImageHeight → bool
no setter
hasImageWidth → bool
no setter
hasMake → bool
no setter
hasModel → bool
no setter
hasOrientation → bool
no setter
hasResolutionUnit → bool
no setter
hasSoftware → bool
no setter
hasUserComment → bool
no setter
hasXResolution → bool
no setter
hasYResolution → bool
no setter
imageDescription ↔ String?
getter/setter pair
imageHeight ↔ int?
getter/setter pair
imageWidth ↔ int?
getter/setter pair
isEmpty → bool
no setter
keys → Iterable<int>
no setter
make ↔ String?
getter/setter pair
model ↔ String?
getter/setter pair
orientation ↔ int?
getter/setter pair
resolutionUnit ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
software ↔ String?
getter/setter pair
sub → IfdContainer
final
userComment ↔ String?
getter/setter pair
values → Iterable<IfdValue>
no setter
xResolution ↔ Rational?
getter/setter pair
yResolution ↔ Rational?
getter/setter pair

Methods

clone() → IfdDirectory
containsKey(int tag) → bool
copy(IfdDirectory other) → void
getDataSize() → int
The size in bytes of the data written by this directory. Can be used to calculate end-of-block offsets.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](Object? tag) → IfdValue?
operator []=(Object? tag, Object? value) → void