JpegComponent class

Constructors

JpegComponent(int hSamples, int vSamples, List<Int16List?> quantizationTableList, int quantizationIndex)

Properties

blocks ↔ List<List<List<int>>>
getter/setter pair
blocksPerColumn ↔ int
getter/setter pair
blocksPerLine ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hSamples ↔ int
getter/setter pair
huffmanTableAC ↔ List<HuffmanNode?>
getter/setter pair
huffmanTableDC ↔ List<HuffmanNode?>
getter/setter pair
pred ↔ int
getter/setter pair
quantizationIndex ↔ int
getter/setter pair
quantizationTable → Int16List?
no setter
quantizationTableList → List<Int16List?>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vSamples ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited