JpegData class

Annotations
  • @internal

Constructors

JpegData()

Properties

adobe ↔ JpegAdobe?
getter/setter pair
comment ↔ String?
getter/setter pair
components → List<ComponentData>
final
exif → ExifData
final
frame ↔ JpegFrame?
getter/setter pair
frames → List<JpegFrame?>
final
hashCode → int
The hash code for this object.
no setterinherited
height → int?
no setter
huffmanTablesAC → List<List<HuffmanNode?>?>
final
huffmanTablesDC → List<List<HuffmanNode?>?>
final
input ↔ InputBuffer
getter/setter pair
jfif ↔ JpegJfif
getter/setter pair
quantizationTables → List<Int16List?>
final
resetInterval ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int?
no setter

Methods

getImage() → Image
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(List<int> bytes) → void
readInfo(List<int> bytes) → JpegInfo?
toString() → String
A string representation of this object.
inherited
validate(List<int> bytes) → bool

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

toFix(double val) → int

Constants

dctSize → const int
dctSize2 → const int
dctZigZag → const List<int>
maxCompsInScan → const int
maxSamplingFactor → const int
numArithTables → const int
numHuffmanTables → const int
numQuantizationTables → const int