JpegFrame class

Annotations
  • @internal

Constructors

JpegFrame()

Properties

components → Map<int, JpegComponent>
final
componentsOrder → List<int>
final
extended ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxHSamples ↔ int
getter/setter pair
maxVSamples ↔ int
getter/setter pair
mcusPerColumn ↔ int
getter/setter pair
mcusPerLine ↔ int
getter/setter pair
precision ↔ int?
getter/setter pair
progressive ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samplesPerLine ↔ int?
getter/setter pair
scanLines ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prepare() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited