OctreeQuantizer class

Constructors

OctreeQuantizer(Image image, {int numberOfColors = 256})

Properties

hashCode → int
The hash code for this object.
no setterinherited
palette ↔ PaletteUint8
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getColorIndex(Color c) → int
getColorIndexRgb(int r, int g, int b) → int
getIndexImage(Image image) → Image
Convert the image to a palette image.
inherited
getQuantizedColor(Color c) → Color
Find the index of the closest color to c in the colorMap.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited