PixelRangeIterator class

Inheritance

Constructors

PixelRangeIterator(Pixel pixel, int x, int y, int width, int height)

Properties

current → Pixel
The current element.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
pixel ↔ Pixel
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x1 ↔ int
getter/setter pair
x2 ↔ int
getter/setter pair
y1 ↔ int
getter/setter pair
y2 ↔ int
getter/setter pair

Methods

moveNext() → bool
Advances the iterator to the next element of the iteration.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited