PngEncoder class

Encode an image to the PNG format.

Inheritance

Constructors

PngEncoder({PngFilter filter = PngFilter.paeth, int? level})

Properties

filter ↔ PngFilter
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isAnimated ↔ bool
getter/setter pair
level ↔ int?
getter/setter pair
output ↔ OutputBuffer?
getter/setter pair
repeat ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber ↔ int
getter/setter pair
supportsAnimation → bool
Does this encoder support animation?
no setteroverride
textData ↔ Map<String, String>?
getter/setter pair

Methods

addFrame(Image image) → void
encode(Image image, {bool singleFrame = false}) → Uint8List
Encode image to the PNG format.
override
finish() → Uint8List?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited