PsdImage class

Implemented types

Constructors

PsdImage(List<int> bytes)

Properties

backgroundColor → Color?
The suggested background color of the canvas.
no setteroverride
channels ↔ int
getter/setter pair
colorMode ↔ PsdColorMode?
getter/setter pair
depth ↔ int?
getter/setter pair
hasAlpha ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
The height of the image canvas.
getter/setter pairoverride-getter
imageResources → Map<int, PsdImageResource>
final
isValid → bool
no setter
layers ↔ List<PsdLayer>
getter/setter pair
mergedImage ↔ Image?
getter/setter pair
mergeImageChannels ↔ List<PsdChannel>
getter/setter pair
numFrames → int
The number of frames that can be decoded.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signature ↔ int?
getter/setter pair
version ↔ int?
getter/setter pair
width ↔ int
The width of the image canvas.
getter/setter pairoverride-getter

Methods

decode() → bool
decodeImage() → Image?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
renderImage() → Image
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

createImageFromChannels(PsdColorMode? colorMode, int? bitDepth, int width, int height, List<PsdChannel> channelList) → Image

Constants

psdSignature → const int
resourceBlockSignature → const int