Pvr2Info class

Implemented types

Constructors

Pvr2Info()

Properties

alphaMask ↔ int
getter/setter pair
backgroundColor ↔ Color?
The suggested background color of the canvas.
getter/setter pairoverride-getter
bitsPerPixel ↔ int
getter/setter pair
blueMask ↔ int
getter/setter pair
flags ↔ int
getter/setter pair
greenMask ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
The height of the image canvas.
getter/setter pairoverride-getter
magic ↔ int
getter/setter pair
mipCount ↔ int
getter/setter pair
numFrames → int
The number of frames that can be decoded.
no setteroverride
numTex ↔ int
getter/setter pair
redMask ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
texDataSize ↔ int
getter/setter pair
width ↔ int
The width of the image canvas.
getter/setter pairoverride-getter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited