Pvr3Info class

Implemented types

Constructors

Pvr3Info()

Properties

backgroundColor ↔ Color?
The suggested background color of the canvas.
getter/setter pairoverride-getter
channelType ↔ int
getter/setter pair
colorSpace ↔ int
getter/setter pair
depth ↔ int
getter/setter pair
flags ↔ int
getter/setter pair
format ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
The height of the image canvas.
getter/setter pairoverride-getter
metadataSize ↔ int
getter/setter pair
mipCount ↔ int
getter/setter pair
numFaces ↔ int
getter/setter pair
numFrames → int
The number of frames that can be decoded.
no setteroverride
numSurfaces ↔ int
getter/setter pair
order ↔ List<int>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ int
The width of the image canvas.
getter/setter pairoverride-getter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited