TgaInfo class

Implemented types

Constructors

TgaInfo()

Properties

backgroundColor → Color?
The suggested background color of the canvas.
no setteroverride
colorMap ↔ Uint8List?
getter/setter pair
colorMapDepth ↔ int
getter/setter pair
colorMapLength ↔ int
getter/setter pair
colorMapOrigin ↔ int
getter/setter pair
colorMapType ↔ int
getter/setter pair
flags ↔ int
getter/setter pair
hasColorMap → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
The height of the image canvas.
getter/setter pairoverride-getter
idLength ↔ int
getter/setter pair
imageOffset ↔ int
getter/setter pair
imageType ↔ TgaImageType
getter/setter pair
numFrames → int
The number of frames that can be decoded.
no setteroverride
offsetX ↔ int
getter/setter pair
offsetY ↔ int
getter/setter pair
pixelDepth ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenOrigin ↔ int
getter/setter pair
width ↔ int
The width of the image canvas.
getter/setter pairoverride-getter

Methods

isValid() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(InputBuffer header) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited