WebPInfo class

Features gathered from the bitstream

Implemented types

Constructors

WebPInfo()

Properties

animLoopCount ↔ int
How many times the animation should loop.
getter/setter pair
backgroundColor ↔ Color?
The suggested background color of the canvas.
getter/setter pairoverride-getter
exif ↔ String
EXIF data string.
getter/setter pair
format ↔ WebPFormat
0 = undefined (/mixed), 1 = lossy, 2 = lossless, 3 = animated
getter/setter pair
frames ↔ List<WebPFrame>
Information about each animation frame.
getter/setter pair
hasAlpha ↔ bool
True if the bitstream contains an alpha channel.
getter/setter pair
hasAnimation ↔ bool
True if the bitstream is an animation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
The height of the image canvas.
getter/setter pairoverride-getter
iccp ↔ Uint8List?
ICCP data.
getter/setter pair
numFrames → int
The number of frames that can be decoded.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ int
The width of the image canvas.
getter/setter pairoverride-getter
xmp ↔ String
XMP data string.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited